---
jupytext:
  cell_metadata_filter: -all
  formats: md:myst
  text_representation:
    extension: .md
    format_name: myst
    format_version: 0.13
    jupytext_version: 1.11.5
kernelspec:
  display_name: Python 3
  language: python
  name: python3
---


# Causas del cambio climático 


Hemos visto como los datos demuestran que la Tierra se está calentando a un ritmo sin precedentes, pero
```{figure} ./images/Causas.gif
---f
scale: 30%
align: center
---
```
<div class="container-iframe"> 
<iframe class="responsive-iframe" src="https://www.youtube.com/embed/CngOrBnRmxI" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe></div>

## Actividades humanas

<!--```{figure} ./images/Actividadhumana.png
---
scale: 50%
align: center
---
Nat Geo Image Collection. Fotografías: izquierda Josh Cogan, derecha Pixabay
```
-->


```{admonition} Importante
:class: danger

Las actividades humanas, en particular la quema de combustibles fósiles, están alterando el sistema climático del planeta desde mediados del siglo XX. 

Además, otras actividades como la deforestación, la urbanización y los cambios en los patrones de vegetación también estan  alterando el clima.


Pero, ¿por qué esta actividades tiene consecuencia sobre el clima de la Tierra? 

<!-- Además, los cambios provocados por el hombre en el uso de la tierra y la cobertura del suelo, como la deforestación, la urbanización y los cambios en los patrones de vegetación también alteran el clima, lo que produce cambios en la reflectividad de la superficie de la Tierra (albedo), en las emisiones causadas por los incendios forestales, en los efectos de las islas de calor urbano y en los cambios en el ciclo natural del agua.-->


```



### Gases de efecto invernadero

El aumento en la concentración de gases de efecto invernadero (GEI) en la atmósfera  esta contribuyendo significativamente al calentamiento global. Los GEI más importantes para este fenomeno son:

::::{grid} 2
:gutter: 5

:::{grid-item-card} Dioxido de carbono (CO$_2$)

```{figure} ./images/co2.jpeg
---
width: 130px
align: center
---
```

:::

:::{grid-item-card} Metano (CH$_4$)

```{figure} ./images/methane.jpg
---
width: 100px
align: center
---
```
:::

:::{grid-item-card} Óxido nitroso (N$_2$O)
```{figure} ./images/N2O.jpg
---
width: 130px
align: center
---
```
:::

:::{grid-item-card} Ozono (O$_3$)
```{figure} ./images/O3.jpg
---
width: 130px
align: center
---
```
:::


:::{grid-item-card} Vapor de agua (H$_2$O)
```{figure} ./images/h2o.jpg
---
scale: 50%
align: center
---
```

:::


::::


En las siguientes gráficas se presenta  las contribuciones de cada continente a las emisiones de gases de efecto invernadero y  la distribución de los diferentes tipos de gases en la atmósfera durante el 2019. Aunque, Asia y  América del Norte son los principales emisores de estos gases,  su impacto sobre el cambio climático es global. Los GEI gases pueden permanecer en la atmósfera por períodos que van de años a miles de años. 

Las actividades humanas han aumentado principalmente las concentración de CO$_2$. Sin embargo, otros GEI, aunque se emiten en menor concetración, pueden ser más nocivos al ser más eficientes en absorver la radiación. Por ejemplo, el metano el 80 veces más efectivo que el CO$_2$. 

```{code-cell}
:tags: [hide-input]
import plotly.graph_objects as go
from plotly.subplots import make_subplots
import plotly.express as px
import numpy as np
import pandas as pd


df = pd.read_csv(r'./datos/owid-co2-data.csv')
world = df[df['country'] == 'World' ]

continents = ['Europe','North America','South America','Asia','Oceania']
co2continents = df[df['country'].isin(continents)]

co2continents = co2continents.rename(columns={"country": "Región"})    

labels = ['Europa','A. del Norte','A. del Sur','Asia','Oceania']

i=0
N= len(labels)
values_ghg = np.zeros(N)

for c in continents:
    df2 = co2continents[co2continents['Región']== c ]
    values_ghg[i] = df2[df2["year"]==2019]["total_ghg"]
      
    i+=1

    
labels_gas = ['methane','nitrous_oxide','co2', "total_ghg"]
labels_gas2 = ['CH_4','NO_2','CO_2', "otros"]
#labels_gas2 = ['Metano','Oxido de nitrogeno','Dioxido de carbono', "otros"]
N = len(labels_gas)
values_gas = np.zeros(N)
i=0
for c in labels_gas:
    values_gas[i] = world[world["year"]==2019][c]
      
    i+=1
    
ghg_tot=values_ghg.sum()
values_ghg=values_ghg/ghg_tot*100

ghg_total = (world[world["year"]==2019]["total_ghg"]).iloc[0]
values_gas = values_gas/ghg_total*100

values_gas[-1]=100-np.sum(values_gas[:3])

# Create subplots: use 'domain' type for Pie subplot
fig = make_subplots(rows=1, cols=2, specs=[[{'type':'domain'}, {'type':'domain'}]])

irises_colors =['rgb(56, 75, 126)', 'rgb(18, 36, 37)', 'rgb(34, 53, 101)',
                'rgb(36, 55, 57)', 'rgb(6, 4, 4)']
night_colors = ['rgb(175, 51, 21)', 'rgb(35, 36, 21)',
                 'rgb(146, 123, 21)','rgb(206, 206, 40)',
                ]

fig.add_trace(go.Pie(labels=labels, values=values_ghg, name="Continente",marker_colors=irises_colors, textinfo='percent+label',showlegend=False ), 1, 1)

fig.add_trace(go.Pie(labels=labels_gas2, values=values_gas, name="Gas",marker_colors=night_colors, textinfo='percent+label',showlegend=False ),
             1, 2)


# Use `hole` to create a donut-like pie chart
fig.update_traces(hole=.4, hoverinfo="label+percent+name")

fig.update_layout(
    title_text="Emision de gases de efecto invernadero (2019)",
    # Add annotations in the center of the donut pies.
    annotations=[dict(text='Total', x=0.18, y=0.5, font_size=20, showarrow=False),
                 dict(text='Gases', x=0.82, y=0.5, font_size=20, showarrow=False)])


fig.update_layout (   
    autosize=False,
    width=780,
    height=400,
    margin=dict(
        l=50,
        r=50,
        b=50,
        t=50,
        pad=4),
    font=dict(
        family="Rockwell",
        size=16,
        #color="RebeccaPurple"
    ),
    plot_bgcolor='rgba(0,0,0,0)'
)

fig.show()
```


### Emisión de CO$_2$
```{figure} ./images/co2.jpg
---
scale: 18%
align: right
---
National Geographic. Foto: Luke Sharrett
```
  Es  irrefutable que las actividades humanas son las  responsables de los recientes incrementos de CO$_2$ en la atmósfera y por ende el principal responsable del calentamiento global.

 Las siguientes gráficas muestran el comportamiento en el tiempo de las emisiones de CO$_2$ por continente. La gráfica de la izquierda corresponde a la emisión de CO$_2$ en toneladas, y la gráfica de la derecha al porcentaje global emitido por cada continente. Actualmente se emiten más de 30 millones de toneladas de CO$_2$ anualmente, cinco veces más que a inicios del siglo XX. 

El 85% de las emisiones globales de CO$_2$ se originaban en Europa y Estados Unidos para 1950. Esta situación ha cambiado en las últimas decadas. Durante la segunda mitad del siglo 20, Asia ha aumentado significativamente sus emisiones de CO$_2$.  


</br>
</br>


```{code-cell}
:tags: [hide-input]

import plotly.graph_objs as go
import pandas as pd
from plotly.subplots import make_subplots

#df = pd.read_csv('./datos/owid-co2-data.csv')
df = pd.read_csv('./datos/owid-co2-data.csv')

continents = ['Europe','North America','South America','Asia','Oceania']
co2continents = df[df['country'].isin(continents)]

co2continents = co2continents.rename(columns={"country": "Región"})    
#fig = make_subplots(rows=1, cols=2)
fig= go.FigureWidget(make_subplots(rows=1, cols=2,horizontal_spacing = 0.13))

labels = ['Europa','América del Norte','América del Sur','Asia','Oceania']
colors= ['rgb(31, 119, 180)', 'rgb(255, 127, 14)',
                       'rgb(44, 160, 44)', 'rgb(214, 39, 40)',
                       'rgb(148, 103, 189)', 'rgb(140, 86, 75)',
                       'rgb(227, 119, 194)', 'rgb(127, 127, 127)',
                       'rgb(188, 189, 34)', 'rgb(23, 190, 207)']
ymax = co2continents["year"].max()+10
ymin = co2continents["year"].min()-10

i=0
for c in continents:
    df = co2continents[co2continents['Región']== c ]
    fig.add_scatter( x = df['year'], y = df['co2'] , name=labels[i],legendgroup=labels[i],text=labels[i], row=1, col=1,
                  line=dict(color=colors[i]) )
    i+=1
    
i=0
for c in continents:
    df = co2continents[co2continents['Región']== c ]
    fig.add_scatter( x = df['year'], y = df["share_global_co2"] ,  name=labels[i], legendgroup=labels[i],text=labels[i], row=1, col=2,
                 showlegend=False, line=dict(color=colors[i]) )
    i+=1


note = 'datos tomados de https://ourworldindata.org/co2-and-greenhouse-gas-emissions'
fig.add_annotation(
    showarrow=False,
    text=note,
    font=dict(size=10), 
    xref='x domain',
    x=2.3,
    yref='y domain',
    y=1.08
    )

fig.update_layout (   
    xaxis_title="Año",
    yaxis_title="co2 [Toneladas]",
    xaxis2_title="Año",
    yaxis2_title="Porcentaje global [%]",
    autosize=False,
    width=900,
    height=400,
    margin=dict(
        l=50,
        r=50,
        b=50,
        t=50,
        pad=4),
    legend=dict(
        title="Región: ", orientation="h", y=1.05, yanchor="bottom", x=0.5, xanchor="center"
    ),
    font=dict(
        family="Rockwell",
        size=16,
        #color="RebeccaPurple"
    ),
    plot_bgcolor='rgba(0,0,0,0)'
)

fig.update_xaxes(
    ticks='outside',
    showline=True,
    linecolor='black',
    gridcolor='lightgrey',
    range=[ymin,ymax],
    mirror=True
)
fig.update_yaxes(
    ticks='outside',
    showline=True,
    linecolor='black',
    gridcolor='lightgrey',
    mirror=True
)


    
fig.show()

```
Los isótopos de carbono (átomos de carbono de diferente peso atómico)  permiten a los/as científicos/as establecer "huellas digitales" de la fuente de las moléculas de dióxido de carbono, revelando  que el aumento de CO$_2$ en la atmósfera está causado principalmente por la quema de combustibles fósiles y los cambios masivos en la cobertura del suelo.  Las industrias de carbón y petróleo juegan un papel muy importante en las emisiones de CO$_2$, tal como se puede apreciar en la siguiente gráfica. 


Los inicios de la industrialización estuvieron dominados por el uso del carbón. Ahora, las emisiones de CO2 estan dominadas por las industrias del petróleo y  el carbón, con una notable contribución de la industria del gas.  


 

```{code-cell}
:tags: [hide-input]
import plotly.graph_objs as go
import numpy as np
import pandas as pd
from plotly.subplots import make_subplots

df = pd.read_csv('./datos/owid-co2-data.csv')
world = df[df['country'] == 'World' ]

fig= go.FigureWidget(make_subplots(rows=1, cols=1))

columns = ['coal_co2_per_capita','gas_co2_per_capita','oil_co2_per_capita','cement_co2_per_capita', 'flaring_co2_per_capita','other_co2_per_capita']
labels = ["Carbón" , "Gas", "Petróleo","Cemento","Quema", "otros"]
colors= ['rgb(31, 119, 180)', 'rgb(255, 127, 14)',
                       'rgb(44, 160, 44)', 'rgb(214, 39, 40)',
                       'rgb(148, 103, 189)', 'rgb(140, 86, 75)',
                       'rgb(227, 119, 194)', 'rgb(127, 127, 127)',
                       'rgb(188, 189, 34)', 'rgb(23, 190, 207)']
ymax = co2continents["year"].max()+10
ymin = co2continents["year"].min()-10

i=0
for c in columns:
    fig.add_scatter( x = world['year'], y = world[c] , name=labels[i],legendgroup=labels[i],text=labels[i],
                     row=1, col=1,
                  line=dict(color=colors[i]) )
    i+=1

    
note = 'datos tomados de https://ourworldindata.org/co2-and-greenhouse-gas-emissions'
fig.add_annotation(
    showarrow=False,
    text=note,
    font=dict(size=10), 
    xref='x domain',
    x=1.6,
    yref='y domain',
    y=-0.255
    )

fig.update_layout (   
    xaxis_title="Año",
    yaxis_title="co2 [Toneladas por persona]",
    autosize=True,
    #width=600,
    #height=400,
    margin=dict(
        l=50,
        r=50,
        b=50,
        t=50,
        pad=4),
    legend=dict(title="Industria",y=.45, yanchor="bottom", x=0.15, xanchor="center"),
    font=dict(
        family="Rockwell",
        size=14,
        #color="RebeccaPurple"
    ),
    plot_bgcolor='rgba(0,0,0,0)'
)

fig.update_xaxes(
    ticks='outside',
    showline=True,
    mirror=True,
    linecolor='black',
    gridcolor='lightgrey',
    range=[1800,ymax]
)
fig.update_yaxes(
    ticks='outside',
    mirror=True,
    showline=True,
    linecolor='black',
    gridcolor='lightgrey'
)


fig.show()

```
Estas tendencias van en aumento, llevando la bandera en contaminación ambiental las industrias del carbón y el petróleo. Estos son combustibles fósiles no renovables, es decir, materiales orgánicos que se encuentran en la corteza terrestre y se han formado hace mucho tiempo. El carbono es básicamente un insumo utilizado para generar electricidad, y el petroleo se una como combustible para el calor y la iluminación.  Su extracción juega un papel muy importante en el cambio climático, llegando a ser catastrófico.

```{admonition} Para saber más...
:class: note

Mira este [mapa](http://www.globalcarbonatlas.org/en/CO2-emissions) global sobre las emisiones y consumo de CO$_2$

```



## Cambios en la radiación solar
```{figure} ./images/Sol.jpg
---
scale: 25%
align: left
---
El sol. Créditos: NASA
```

Durante cada ciclo de 11 años, el Sol sufre varios cambios en su actividad y apariencia. Los niveles de radiación solar aumentan o disminuyen, al igual que la cantidad de material que el Sol expulsa al espacio, el tamaño o la cantidad de manchas solares y erupciones solares. Estos cambios pueden tener un impacto en el clima de la Tierra.

De hecho, los estudios muestran que la variabilidad solar ha desempeñado un papel en los cambios climáticos del pasado. Por ejemplo, una disminución en la actividad solar junto con una mayor actividad volcánica ayudó a desencadenar la Pequeña Edad de Hielo. **Sin embargo es extremadamente improbable que el Sol este causado la tendencia de calentamiento global observada durante el último medio siglo.**

Esta gráfica compara la evolución de la anomalía térmica (en rojo) con la energía solar que recibe la Tierra en vatios por metro cuadrado (linea azul). Desde la segunda mitad del siglo XX, la actividad solar ha decendido ligeramente, mientras que la temperatura global presenta un aumento notable.



```{code-cell}
:tags: [hide-input]

import numpy as np
import pandas as pd
import plotly.graph_objs as go

df = pd.read_csv('./datos/historical_tsi.csv')
df = df.rename(columns={"time (yyyy)": "Time", "Irradiance (W/m^2)": "II"})

df2 = pd.read_table('./datos/graph.txt',
                   skiprows=[0,1,2,4], sep='\s+')
df2 = df2.rename(columns={"No_Smoothing": "temperature anomaly", "Lowess(5)": "lowess"})


data = [
    go.Scatter(x = df['Time'], y=df['II'], name='Irradiancia'),
    go.Scatter(x = df2['Year'], y= df2['temperature anomaly'], name='Anomalía', yaxis='y2')
]

y1 = go.layout.YAxis(title='Irradiancia solar [W / m^2]', color='SteelBlue',
    linecolor='black',
    mirror=True )

y2 = go.layout.YAxis(title= 'Anomalía Térmica', color='Red',
    linecolor='black',
    mirror=True)
y2.update(overlaying='y', side='right')

layout = go.Layout(yaxis1 = y1, yaxis2 = y2)

fig = go.Figure(data=data, layout=layout)

fig.add_vline(x=1957, line_dash="dot", row="all", col="all",
              annotation_text="Máximo <br> era moderna", 
              annotation_position="bottom right",
             annotation=dict(font_size=15, font_family="Times New Roman"),)

fig.update_layout (   
    xaxis_title="Año",
    yaxis_title="Irradiancia solar [W / m^2]",
    autosize=True,
    #width=790,
    #height=500,
    margin=dict(
        l=50,
        r=50,
        b=50,
        t=50,
        pad=4),
    font=dict(
        family="Rockwell",
        size=16,
        #color="RebeccaPurple"
    ),
    legend=dict(
        title=None, orientation="h", y=1.05, yanchor="bottom", x=0.5, xanchor="center"
    ),
    plot_bgcolor='rgba(0,0,0,0)'
)

fig.update_xaxes(
    ticks='outside',
    showline=True,
    linecolor='black',
    mirror=True,
    range=[1600,2020],
    rangeslider=dict(
            visible = True,
                
            )
)


fig.add_vrect(x0=1645, x1=1715, 
              annotation_text="Pequeña edad<br> de hielo", annotation_position="top left",
              annotation=dict(font_size=15, font_family="Times New Roman"),
              fillcolor="green", opacity=0.25, line_width=0)


display(fig)
```

## Erupciones volcánicas
```{figure} ./images/Volcanes.jpg
---
scale: 28%
align: left
---
Nat Geo. Foto: Madden, Robert 
```

Las erupciones volcánicas  pueden liberar dióxido de azufre (SO2) a la atmósfera, que se convierte en aerosoles de sulfato. Estos aerosoles reflejan la radiación solar y aumentan la dispersión de la luz, lo que contribuye al enfriamiento del clima. Aunque estos efectos suelen ser temporales y pueden durar de meses a unos pocos años, las erupciones volcánicas masivas tienen el potencial de causar cambios climáticos más duraderos. 

</br>
</br>
</br>

Las emisiones volcánicas también pueden interactuar con otros factores del clima, como la concentración de gases de efecto invernadero y la circulación atmosférica, lo que puede resultar en efectos climáticos complejos y difíciles de predecir.

```{admonition} Sin embargo
:class: danger

Las contribuciones humanas al ciclo del carbono son más de 100 veces superiores a las de todos los volcanes del mundo combinados.
```



# ¿Es tarde para prevenir el cambio climático? 

Las actividades humanas han causado el reciente cambio en el clima y sus efectos son irreversibles. Sin embargo, si se detienen las emisiones de GEI, el aumento de la temperatura puede estabilizarse en algunos años, aunque permanecería elevada por varios siglos. 

En esta gráfica se proyectan los efectos de la redución en la emisión de gases de efecto invernadero para varios escenarios. Si se mantinen las políticas actuales se proyecta un incremento en la temperatura de 2.7 grados. 

Para una estimación optimista en la que todos los paises cumplen sus metas de reducción de emisiones, el aumento en la temperatura se limitario a alrededor de 2 grados para 2100. 

Para obtener un aumneto en la temperatura de 1.5 grados, las emisiones de GEI deberán tener una disminución significativa para 2030.

```{code-cell}
:tags: [remove-input]

import pandas as pd
import plotly.graph_objs as go

df =pd.read_excel("./datos/CAT_2022_Warming_projections_global_update.xlsx",sheet_name=1, skiprows=14)

names=df.columns[3:]

ff0 = df.loc[0,[ii for ii in names]]
ff1 = df.loc[1,[ii for ii in names]]

ff3 = df.loc[3,[ii for ii in names]]
ff4 = df.loc[4,[ii for ii in names]]


ff6 = df.loc[6,[ii for ii in names]]
ff7 = df.loc[7,[ii for ii in names]]
ff8 = df.loc[8,[ii for ii in names]]

ff9 = df.loc[9,[ii for ii in names]]
upper_bound = go.Scatter(
        name='+',
        x=names,
        y=ff0,
        mode='lines',
        line=dict(width=0.5,
                 color="#d62728"),
        #fillcolor='rgba(68, 68, 68, 0.1)',
        fill='tonexty',
        showlegend=False )

trace1 = go.Scatter(
        name='Historico',
        x=names,
        y=ff9,
        mode='lines',
        line=dict(color='black'),
        #fillcolor='rgba(68, 68, 68, 0.1)',
        #fill='tonexty',
        showlegend=False )

trace2 = go.Scatter(
        name='cambio',
        x=names,
        y=ff7,
        mode='lines',
        line=dict(color='#17becf',dash="dash"),
        #fillcolor='rgba(68, 68, 68, 0.1)',
        #fill='tonexty',
        showlegend=False )

lower_bound = go.Scatter(
        name='-',
        x=names,
        y=ff1,
        mode='lines',
        line=dict(width=0.5, color="#d62728"),
        showlegend=False)

upper_bound_1 = go.Scatter(
        name='+',
        x=names,
        y=ff3,
        mode='lines',
        line=dict(width=0.5,
                 color="#2ca02c"),
        #fillcolor='rgba(68, 68, 68, 0.1)',
        fill='tonexty',
        showlegend=False )

lower_bound_1 = go.Scatter(
        name='-',
        x=names,
        y=ff4,
        mode='lines',
        line=dict(width=0.5, color="#2ca02c"),
        showlegend=False)

upper_bound_2 = go.Scatter(
        name='+',
        x=names,
        y=ff6,
        mode='lines',
        line=dict(width=0.5,
                 color="#17becf"),
        #fillcolor='rgba(68, 68, 68, 0.1)',
        fill='tonexty',
        showlegend=False )

lower_bound_2 = go.Scatter(
        name='-',
        x=names,
        y=ff8,
        mode='lines',
        line=dict(width=0.5, color="#17becf"),
        showlegend=False)


data = [lower_bound, upper_bound,lower_bound_1, upper_bound_1,lower_bound_2, upper_bound_2, trace1,trace2]

layout = go.Layout(
        yaxis=dict(title='Emisión de GEI [giga-toneladas]',
                   showline=True,
                   linecolor='black',
                   gridcolor='lightgrey',
                   mirror=True,
                  ),
        #title='Volatility Visualization',
        xaxis=dict(title='Año', showline=True,
                   linecolor='black',
                   gridcolor='lightgrey',
                   mirror=True ,  
            rangeslider=dict(
            visible = True,
                
            ),
            type='date'
        ),        
    showlegend = True,
    autosize=True,
    #width=800,
    #height=600,
    margin=dict(
        l=50,r=50,b=50,t=50,pad=4),
    font=dict(
        family="Rockwell",
        size=15),
    plot_bgcolor='rgba(0,0,0,0)')

fig = go.Figure(data=data, layout=layout)

fig.add_annotation(dict(font=dict(size=15),
                                        x=0.82,
                                        y=0.81,
                                        showarrow=False,
                                        text="+ 2.6-2.9 C",
                                        textangle=0,
                                        xanchor='left',
                                        xref="paper",
                                        yref="paper"))

fig.add_annotation(dict(font=dict(size=15),
                                        x=0.8,
                                        y=0.35,
                                        showarrow=False,
                                        text="+ 1.8-2.0 C",
                                        textangle=0,
                                        xanchor='left',
                                        xref="paper",
                                        yref="paper"))

fig.add_annotation(dict(font=dict(size=15),
                                        x=0.9,
                                        y=0.09,
                                        showarrow=False,
                                        text="+ 1.5 C",
                                        textangle=0,
                                        xanchor='left',
                                        xref="paper",
                                        yref="paper"))

fig.add_annotation(dict(font=dict(size=10),
                                        x=0.5,
                                        y=0.01,
                                        showarrow=False,
                                        text="datos tomados de  Climate Action Tracker",
                                        textangle=0,
                                        xanchor='left',
                                        xref="paper",
                                        yref="paper"))

fig.show()
```

## Energías renovables
Las energías renovables son energías obtenidas de fuentes como el Sol y el viento que se renuevan naturalmente y no se agotan. La renovación natural de estas fuentes de energía hace que sean ideales para garantizar un modelo de energía sostenible. Quizá el argumento más importante para usar energías renovables es que no liberan dióxido de carbono o contaminantes al medio ambiente y tampoco genera polución de aire. Son energías limpias. Algunas como la geotérmica, que liberan dióxido de carbono, son neutras en carbono.

```{figure} ./images/TiposDeEnergia.gif
---
width: 500 px
align: center
---
```

<!-- ****************************************************************************************************** 
 Tipos de Energías
 1. hidraulica
 2. biomasa
 3. solar
 4. eólica
 5. geotérmica
-->


Algunos tipos de energías renovables son los siguientes:

````{grid} 1
:gutter: 4

```{grid-item-card} Energía hidroeléctrica

:::{figure} ./images/hidraulica.jpg
---

width: 130px
align: left
---
:::

Es una de las fuentes de energías más antiguas usadas por la humanidad y abundantes, la cual usa el flujo natural del agua para generar electricidad. Las hidroeléctricas aprovechan una diferencia de elevación para generar energía. En su interior una hidroeléctrica contiene turbinas que al girar permiten inducir una corriente eléctrica. Esto ocurre debido a un fenómeno de inducción magnética.

```

```{grid-item-card} Energía Biomasa

:::{figure} ./images/biomasa.jpg
---
width: 150px
align: left
---
:::

Es un tipo de energía que es derivada de materia orgánica previamente viva, a la que se conoce como biomasa. La energía biomasa aprovecha desperdicios orgánicos de actividades agrícolas, industriales y de poda de árboles. Esta se usa como biocombustible y puede usarse para generar energía eléctrica por combustión al igual que el combustible fósil. Como el carbono de la biomasa ya hace parte del ciclo del carbono se considera a la biomasa como neutra en carbono.

>La energía biomasa es competitiva respecto a la energía basada en carbono y combustibles fósiles. Los biocombustibles son una buena alternativa a los de origen fósil. Pero, ¿ la energía biomasa es contaminante o no?. Lo cierto es que esta energía es neutra en carbono. Esto significa que el carbono liberado por esta fuente no contribuye al aumento de gases de efecto invernadero. La razón de esto es que el carbono presente en la biomasa ya hace parte del ciclo natural del carbono. Al contrario del combustible fósil el cual naturalmente no participa activamente en este


```

```{grid-item-card} Energía Solar

:::{figure} ./images/solar.jpg
---
width: 150px
align: left
---
:::
La cantidad de energía solar que llega a la superficie de la tierra en una hora es suficiente para cubrir el consumo de energía de todo el mundo durante un año. Las tecnologías de energía solar transforman la radiación solar en energía eléctrica a través de paneles solares o de espejos que concentran la radiación solar. Los paneles solares se componen de celdas fotovoltaicas las cuales funcionan de acuerdo con el efecto fotoeléctrico. Las plantas de concentración de radiación solar usan espejos para dirigir los rayos de luz hacía un colector de calor, como un tubo metálico, el cual calienta agua hasta generar vapor de agua, que finalmente puede usarse para mover una turbina y generar electricidad.
```

```{grid-item-card} Energía Eólica

:::{figure} ./images/eolica.jpg
---
width: 150px
align: left
---
:::
Esta energía se produce mediante de turbinas de viento que transforman la energía cinética que produce el viento en energía eléctrica. La energía eólica es realmente un subproducto de la energía del Sol y la de rotación de la Tierra sobre sí misma. Como el viento es una fuente abundante decimos que la energía eólica es una fuente sostenible.
```

```{grid-item-card} Energía geotérmica

:::{figure} ./images/geotermica.jpg
---
width: 150px
align: left
---
:::

La energía geotérmica proviene de reservorios térmicos de agua caliente que existen naturalmente o han sido creados artificialmente a distintas temperaturas y profundidades de la superficie terrestre. Hay procesos naturales debajo de la superficie que generan calor (por ejemplo, el magma presente en un volcán) este calor a veces traspasa la superficie en forma de vapor de agua. Una planta geotérmica usa este vapor que emana de la superficie para mover unas turbinas que finalmente generan la electricidad. La energía geotérmica se renueva naturalmente y es limpia (no emite gases de efecto invernadero).
```
````


```{admonition} Energía biomasa 
:class: tip
De acuerdo con [Alcogen](https://acolgen.org.co) (Asociación Colombiana de Generadores de Energía Eléctrica) el 69.4% de la energía eléctrica instalada en Colombia proviene de fuentes renovables. El 68.3% proviene de energía hidroeléctrica, el 0.9% de energía biomasa, un 0.1% de energía solar y otro 0.1% de energía eólica. El resto proviene de energía térmica no renovable. En la actualidad se están planeando proyectos de generación de energía por biomasa [biomasa](https://www.elespectador.com/economia/la-planta-de-biomasa-que-generara-energia-verde-para-ecopetrol/) de eucalipto y de energía [geotérmica](https://www.piensageotermia.com/ecopetrol-baker-hughes-y-chec-se-alian-para-impulsar-energia-geotermica-en-colombia/).
```


## Actividad: Salvando al planeta
:::{figure} ./images/save.jpg
---
width: 300px
align: left
---
:::

Ahora que sabes cuales son las causas más relevantes del cambio climático y lo terribles efectos que hemos venido presenciando, es hora de buscar posibles soluciones. 

**Actividad Grupal: Identificando Consecuencias, Retos Tecnológicos y Acciones Relativas al Cambio Climático**
Duración: 25-35 minutos

En grupos de tres persona o más deben elegir alguna «Consecuencia Puntual» diferente en base a sus gustos o interés y:

* **Identificar** las posibles causas eligiendo entre la «Lista de consecuencias».
* **Investigar** las relaciones precisas con el cambio climático y sus consecuencias.
* **Proponer** alguna solución / accción para afrontar las consecuencias si ocurren / estrategia de prevención. 
* **Plantear** los retos tecnológicos que hacen falta para afrontar las consecuencias / si estamos preparados o no para afrontarlas.

Luego de 10-15 minutos cada grupo debe registrar en un documento de Word las respuestas a cada petición en forma de una lista de ideas. Deben poner un título, la «Consecuencia Puntual» elegida. Se deja un tiempo de 5 minutos para esta tarea. Al finalizar, deben enviar por el canal del Mattermost de su Colegio el PDF con su respuesta. Luego, cada grupo presenta a todos su solución y se presenta una discusión en torno a esta; dentro de 10-15 minutos. 


|Consecuencias Puntuales|
|--|
|Incremento de enfermedades respiratorias |
|Perdida de la biodiversidad del mar|
|Perdida de zonas agrícolas|
|Disminución de territorio|
|Desplazamientos climáticos|
|Lluvías ácidas|
|Salinificación de rios o fuentes hídricas de agua dulce|
|Migraciones anómalas de bandadas de aves / Reducción de poblaciones de animales que migran, por ejemplo: la mariposa monarca|
|Reducción de poblaciones de animales que hibernan, por ejemplo: por la dificultad de prepararse para el invierno|
|Perdida de cultivos agricolas o cosechas a causa del clima|

|Lista de Consecuencias|
|--|
|Derretimiento de los casquetes polares y de la antartica|
|Aumento del nivel del mar|
|Aumento de la temperatura media global|
|Intensificación de sequías e inundaciones|
|Aumento de la salinidad del mar|
|Contaminación del aire por polución / dióxido de carbono|

*Reflexiones:*
¿Cuáles de estas «Consecuencias Puntuales» tienen una solución o pueden afrontarse por los seres humanos?
¿Cómo se puede relacionar esto con lo que hace Makesens? 
¿Qué papel juegan las estaciones de medición de variables climáticas?



